@@ -1,23 +1,14 @@
-# -*- coding: utf-8 -*-
 # flake8: noqa
 # disable flake check on this file because some constructs are strange
 # or redundant on purpose and can't be disable on a line-by-line basis
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import ast
 import inspect
 import sys
 
-import six
-
 import _pytest._code
 import pytest
 from _pytest._code import Source
 
-failsonjython = pytest.mark.xfail("sys.platform.startswith('java')")
-
 
 def test_source_str_function():
     x = Source("3")
@@ -35,11 +26,11 @@ def test_source_str_function():
 
 
 def test_unicode():
-    x = Source(u"4")
+    x = Source("4")
     assert str(x) == "4"
-    co = _pytest._code.compile(u'u"å"', mode="eval")
+    co = _pytest._code.compile('"å"', mode="eval")
     val = eval(co)
-    assert isinstance(val, six.text_type)
+    assert isinstance(val, str)
 
 
 def test_source_from_function():
@@ -48,7 +39,7 @@ def test_source_from_function():
 
 
 def test_source_from_method():
-    class TestClass(object):
+    class TestClass:
         def test_method(self):
             pass
 
@@ -122,7 +113,7 @@ def test_source_strip_multiline():
 def test_syntaxerror_rerepresentation():
     ex = pytest.raises(SyntaxError, _pytest._code.compile, "xyz xyz")
     assert ex.value.lineno == 1
-    assert ex.value.offset in (4, 5, 7)  # XXX pypy/jython versus cpython?
+    assert ex.value.offset in {5, 7}  # cpython: 7, pypy3.6 7.1.1: 5
     assert ex.value.text.strip(), "x x"
 
 
@@ -135,7 +126,7 @@ def test_isparseable():
     assert not Source(chr(0)).isparseable()
 
 
-class TestAccesses(object):
+class TestAccesses:
     source = Source(
         """\
         def f(x):
@@ -163,7 +154,7 @@ class TestAccesses(object):
         assert len(values) == 4
 
 
-class TestSourceParsingAndCompiling(object):
+class TestSourceParsingAndCompiling:
     source = Source(
         """\
         def f(x):
@@ -340,7 +331,7 @@ class TestSourceParsingAndCompiling(object):
 
 
 def test_getstartingblock_singleline():
-    class A(object):
+    class A:
         def __init__(self, *args):
             frame = sys._getframe(1)
             self.source = _pytest._code.Frame(frame).statement
@@ -487,7 +478,7 @@ def test_getfslineno():
     assert fspath.basename == "test_source.py"
     assert lineno == _pytest._code.getrawcode(f).co_firstlineno - 1  # see findsource
 
-    class A(object):
+    class A:
         pass
 
     fspath, lineno = getfslineno(A)
@@ -498,7 +489,7 @@ def test_getfslineno():
 
     assert getfslineno(3) == ("", -1)
 
-    class B(object):
+    class B:
         pass
 
     B.__name__ = "B2"
@@ -506,19 +497,19 @@ def test_getfslineno():
 
 
 def test_code_of_object_instance_with_call():
-    class A(object):
+    class A:
         pass
 
     pytest.raises(TypeError, lambda: _pytest._code.Source(A()))
 
-    class WithCall(object):
+    class WithCall:
         def __call__(self):
             pass
 
     code = _pytest._code.Code(WithCall())
     assert "pass" in str(code.source())
 
-    class Hello(object):
+    class Hello:
         def __call__(self):
             pass
 
@@ -627,7 +618,7 @@ x = 3
     assert str(source) == "raise ValueError(\n    23\n)"
 
 
-class TestTry(object):
+class TestTry:
     source = """\
 try:
     raise ValueError
@@ -654,7 +645,7 @@ else:
         assert str(source) == "    raise KeyError()"
 
 
-class TestTryFinally(object):
+class TestTryFinally:
     source = """\
 try:
     raise ValueError
@@ -671,7 +662,7 @@ finally:
         assert str(source) == "    raise IndexError(1)"
 
 
-class TestIf(object):
+class TestIf:
     source = """\
 if 1:
     y = 3
@@ -727,7 +718,7 @@ something
 
 
 def test_getstartingblock_multiline():
-    class A(object):
+    class A:
         def __init__(self, *args):
             frame = sys._getframe(1)
             self.source = _pytest._code.Frame(frame).statement
