@@ -1194,6 +1194,21 @@ def test_help_and_version_after_argument_error(testdir):
     assert result.ret == ExitCode.USAGE_ERROR
 
 
+def test_help_formatter_uses_py_get_terminal_width(testdir, monkeypatch):
+    from _pytest.config.argparsing import DropShorterLongHelpFormatter
+
+    monkeypatch.setenv("COLUMNS", "90")
+    formatter = DropShorterLongHelpFormatter("prog")
+    assert formatter._width == 90
+
+    monkeypatch.setattr("py.io.get_terminal_width", lambda: 160)
+    formatter = DropShorterLongHelpFormatter("prog")
+    assert formatter._width == 160
+
+    formatter = DropShorterLongHelpFormatter("prog", width=42)
+    assert formatter._width == 42
+
+
 def test_config_does_not_load_blocked_plugin_from_args(testdir):
     """This tests that pytest's config setup handles "-p no:X"."""
     p = testdir.makepyfile("def test(capfd): pass")
